from distutils.core import setup

setup(name='ansible-run', version='1.1', url='https://www/github.com/moshloop/ansible-run',
    author='Moshe Immerman', author_email='firstname.surname@gmail.com',
  data_files=[('/usr/local/bin/ansible-run', ['bin/ansible-run'])])